@@ -34,6 +34,7 @@ EffingMain::EffingMain(QWidget *parent) :
     connect(ui->actionConfigure,SIGNAL(triggered()),this,SLOT(process_configure_menu()));
     connect(ui->openFacebookButton,SIGNAL(clicked()),this,SIGNAL(launch_facebook()));
     connect(ui->statusEdit,SIGNAL(textChanged()),this,SLOT(status_text_changed()));
+    ui->placeButton->setVisible(false);
 }
 
 EffingMain::~EffingMain()
@@ -49,7 +50,7 @@ void EffingMain::initial_config()
 
 void EffingMain::set_status(QString messageHtml)
 {
-    ui->currentStatusEdit->setHtml(messageHtml);
+    ui->statusBrowser->setHtml(messageHtml);
 }
 
 void EffingMain::on_submitButton_clicked()
@@ -63,7 +64,7 @@ void EffingMain::on_submitButton_clicked()
 
 void EffingMain::set_status_not_logged_in()
 {
-    ui->currentStatusEdit->setText(tr("Not logged in."));
+    ui->statusBrowser->setText(tr("Not logged in."));
 }
 
 void EffingMain::on_refreshButton_clicked()
