@@ -21,6 +21,7 @@
 #include "fbactions.h"
 #include "logindialog.h"
 #include "constants.h"
+#include "messagedto.h"
 #include <QByteArray>
 #include <QtNetwork/QNetworkAccessManager>
 #include <QtNetwork/QNetworkRequest>
@@ -30,7 +31,6 @@
 #include <QVariantMap>
 #include <QDebug>
 #include <QtScript/QScriptEngine>
-#include <QtScript/QScriptValue>
 
 FbActions::FbActions(QObject *parent) :
     QObject(parent)
@@ -40,21 +40,17 @@ FbActions::FbActions(QObject *parent) :
 
 void FbActions::request_status()
 {
-    QString message;
-    QDateTime timestamp;
     QString token = get_auth_token();
     if (token.isNull() || token.isEmpty()) {
-        message = tr("Not logged in to Facebook");
-        timestamp = QDateTime::currentDateTime();
-        emit status_available(message,timestamp);
+        emit_simple_message(tr("Not logged in to Facebook"));
     } else {
-        emit status_available(tr("Requesting status from Facebook..."),QDateTime::currentDateTime());
+        emit_simple_message(tr("Requesting status from Facebook..."));
         QUrl url;
         url.setScheme("https");
         url.setHost(AUTH_HOST);
         url.setPath("/me/statuses");
         url.addQueryItem("access_token",token);
-        url.addQueryItem("limit","1");
+        url.addQueryItem("limit","10");
         url.addQueryItem("fields","id,message,updated_time,comments");
         qDebug()<<"about to request url: "<<url.toString();
         QNetworkRequest req(url);
@@ -80,39 +76,53 @@ QString FbActions::get_auth_token()
 
 void FbActions::handle_http_response(QNetworkReply *reply)
 {
-    QString message;
-    QDateTime timestamp = QDateTime::currentDateTime();
+    MessageDTO messageDto;
+    messageDto.setCurrentTimestamp();
     if (reply->error()==QNetworkReply::NoError) {
-        emit status_available(tr("Recieved reply from Facebook..."),timestamp);
         QByteArray bytes = reply->readAll();
         qDebug()<<"http response: "<<bytes;
         QScriptEngine script_engine;
         QScriptValue script_value = script_engine.evaluate("("+QString(bytes)+")");
         if (script_value.isError())
         {
-            message = tr("Unable to parse result.");
+            messageDto.setText(tr("Unable to parse result."));
         }
         else if (script_value.property("data").isValid())
         {
             //Response from a request for status is a data node
             QScriptValue data = script_value.property("data");
-            if (data.isArray() && data.property("length").toInt32() > 0)
+            messageDto.setMessageType(MessageDTO::COLLECTION);
+            if (data.isArray())
             {
-                QScriptValue data_entry = data.property("0");
-                message = data_entry.property("message").toString();
-                if (data_entry.property("updated_time").isDate())
-                {
-                    timestamp = data_entry.property("updated_time").toDateTime();
-                }
-                else
-                {
-                    //The toDateTime function does not seem to properly parse this date time
-                    QString timestamp_str = data_entry.property("updated_time").toString();
-                    timestamp = QDateTime::fromString(timestamp_str,Qt::ISODate);
-                    //QT doesn't seem to like the time zone data, so we set it explicitly to UTC and then convert to local.
-                    timestamp.setTimeSpec(Qt::UTC);
-                    timestamp = timestamp.toLocalTime();
-
+                int arrayCount = data.property("length").toInt32();
+                for (int index=0; index<arrayCount; index++) {
+                    MessageDTO statusMessage;
+                    QScriptValue data_entry = data.property(QString("%1").arg(index));
+                    statusMessage.setMessageType(MessageDTO::STATUS);
+                    statusMessage.setText(data_entry.property("message").toString());
+                    statusMessage.setTimestamp(parseTime(data_entry.property("updated_time")));
+                    if (data_entry.property("comments").isValid()) {
+                        QScriptValue comment_data = data_entry.property("comments").property("data");
+                        if (comment_data.isValid() && comment_data.isArray())
+                        {
+                            int commentArrayCount = comment_data.property("length").toInt32();
+                            for (int commentIndex=0; commentIndex<commentArrayCount; commentIndex++) {
+                                MessageDTO commentMessage;
+                                QScriptValue comment_data_entry = comment_data.property(QString("%1").arg(commentIndex));
+                                commentMessage.setMessageType(MessageDTO::COMMENT);
+                                commentMessage.setText(comment_data_entry.property("message").toString());
+                                commentMessage.setTimestamp(parseTime(comment_data_entry.property("created_time")));
+                                QScriptValue fromNode = comment_data_entry.property("from");
+                                if (fromNode.isValid())
+                                {
+                                    QScriptValue nameNode = fromNode.property("name");
+                                    if (nameNode.isValid()) commentMessage.setAuthor(nameNode.toString());
+                                }
+                                statusMessage.addChild(commentMessage);
+                            }
+                        }
+                    }
+                    messageDto.addChild(statusMessage);
                 }
             }
         }
@@ -120,36 +130,34 @@ void FbActions::handle_http_response(QNetworkReply *reply)
         {
             //response from successful submit of post is an id value
             emit status_successfully_set();
-            message = tr("Status successfully submitted.");
+            messageDto.setText(tr("Status successfully submitted."));
             request_status();
         }
         else
         {
-            message = tr("Unknown response from Facebook.");
+            messageDto.setText(tr("Unknown response from Facebook."));
         }
     } else {
-        message = QString(tr("Network error: %1")).arg(reply->errorString());
+        messageDto.setText(QString(tr("Network error: %1")).arg(reply->errorString()));
     }
-    emit status_available(message,timestamp);
+    emit status_available(messageDto.getFormattedMessage());
     reply->deleteLater();
 }
 
 void FbActions::unauthorize()
 {
     settings_manager.clear_facebook_auth();
-    QString message = tr("Facebook Authorization Removed.");
-    QDateTime timestamp = QDateTime::currentDateTime();
-    emit status_available(message,timestamp);
+    emit_simple_message(tr("Facebook Authorization Removed."));
 }
 
 void FbActions::set_status(QString status)
 {
     QString token = get_auth_token();
     if (token.isNull() || token.isEmpty()) {
-        emit status_available(tr("Not logged in to Facebook"),QDateTime::currentDateTime());
+        emit_simple_message(tr("Not logged in to Facebook."));
         return;
     }
-    emit status_available(tr("Sending status to Facebook..."),QDateTime::currentDateTime());
+    emit_simple_message(tr("Sending status to Facebook..."));
     QUrl url;
     url.setScheme("https");
     url.setHost(AUTH_HOST);
@@ -162,3 +170,29 @@ void FbActions::set_status(QString status)
     access_manager.post(req,post_data.toAscii());
 }
 
+void FbActions::emit_simple_message(QString text)
+{
+    MessageDTO messageDto;
+    messageDto.setText(text);
+    messageDto.setCurrentTimestamp();
+    emit status_available(messageDto.getFormattedMessage());
+}
+
+QDateTime FbActions::parseTime(QScriptValue jsonNode)
+{
+    QDateTime time;
+    if (jsonNode.isDate())
+    {
+        time = jsonNode.toDateTime();
+    }
+    else
+    {
+        //The toDateTime function does not seem to properly parse this date time
+        QString timestamp_str = jsonNode.toString();
+        time = QDateTime::fromString(timestamp_str,Qt::ISODate);
+        //QT doesn't seem to like the time zone data, so we set it explicitly to UTC and then convert to local.
+        time.setTimeSpec(Qt::UTC);
+        time = time.toLocalTime();
+    }
+    return time;
+}
